import{r as i,b as x,j as e}from"./app--5U4-9K0.js";function f({option:s}){return e.jsx("option",{value:s.value,disabled:s.disabled,children:s.label})}const p=i.memo(function({id:t,label:r,required:n,value:c,options:o,...h}){const d=x(t,"change","value"),u=i.useRef(c);function m(a){const l=a.target.value;l!==u.current&&(u.current=l,d(l))}return e.jsxs("div",{className:"rl-form-group",children:[r&&e.jsxs("label",{htmlFor:t,children:[r," ",n&&e.jsx("span",{className:"rl-required",children:"*"})]}),e.jsx("select",{id:t,value:c,...h,required:n,onChange:m,children:o.map(a=>e.jsx(f,{option:a},a.value))})]})});p.displayName="Select";export{p as default};
