import{r as x,a as m,j as e}from"./app--5U4-9K0.js";function c({id:r,label:a,defaultValue:n,...s}){const{handleBlur:t,handleKeyDown:o}=m(r,n),l=s.required;return e.jsxs("div",{className:"rl-form-group",children:[a&&e.jsxs("label",{htmlFor:r,children:[a," ",l&&e.jsx("span",{className:"rl-required",children:"*"})]}),e.jsx("textarea",{id:r,...s,onBlur:t,onKeyDown:o,defaultValue:n})]})}const u=x.memo(c);u.displayName="Textarea";export{u as default};
