import{r as x,a as m,j as e}from"./app--5U4-9K0.js";function p({id:n,label:r,defaultValue:t,type:o="text",...s}){const{handleBlur:a,handleKeyDown:u}=m(n,t),l=s.required;return e.jsxs("div",{className:"rl-form-group",children:[r&&e.jsxs("label",{htmlFor:n,children:[r," ",l&&e.jsx("span",{className:"rl-required",children:"*"})]}),e.jsx("input",{type:o,id:n,...s,onBlur:a,onKeyDown:u,defaultValue:t})]})}const c=x.memo(p);c.displayName="TextInput";export{c as default};
