import{r as a,b as x,j as e}from"./app--5U4-9K0.js";const m=a.memo(function({label:r,id:s,required:c,defaultChecked:o,...n}){const t=x(s,"change","checked"),h=a.useCallback(l=>{t(l.target.checked)},[t]);return e.jsxs("div",{className:"rl-form-flex-control",children:[e.jsx("input",{...n,type:"checkbox",id:s,defaultChecked:o,onChange:h,required:c}),e.jsxs("label",{htmlFor:s,children:[r," ",c&&e.jsx("span",{className:"rl-required",children:"*"})]})]})});m.displayName="Checkbox";export{m as default};
