*{box-sizing:border-box}body{margin:0;padding:0}.rl-container{display:contents}.rl-flex{display:flex}.rl-flex-row{flex-direction:row}.rl-flex-col{flex-direction:column}.rl-flex-wrap{flex-wrap:wrap}.rl-required{color:red}.rl-no-link-decoration,.rl-no-link-decoration:hover,.rl-no-link-decoration:active{text-decoration:none;color:inherit}.rl-close-button{position:absolute;top:0;right:0;background-color:transparent;border:none;font-size:1rem;cursor:pointer;color:inherit}.rl-form-flex-control{display:flex;align-items:center;gap:.5rem}.rl-form-control-group{display:flex;gap:.5rem}.rl-form-inline-label{display:inline}.rl-form-inline-label small{display:block}.rl-form-control-caption{color:#777}.rl-component{display:contents}.rl-stale>*{opacity:.5;transition:opacity .5s linear}
