import{r as x,j as f}from"./app--5U4-9K0.js";function w({children:m,direction:e="col",flexWrap:s="nowrap",justifyContent:l="start",alignItems:t="normal",alignContent:a="normal",gap:o="0",...r}){const u=x.useMemo(()=>({...r.style,gap:o,justifyContent:l,alignItems:t,alignContent:a}),[o,l,t,a,r.style]),c=x.useMemo(()=>`rl-flex rl-flex-${e} ${s==="wrap"?"rl-flex-wrap":""}`,[e,s]);return f.jsx("div",{className:c,style:u,...r,children:m})}export{w as default};
